Class: McpToolkit::Errors::ConfigurationError
- Inherits:
-
Base
- Object
- Base
- McpToolkit::Errors::ConfigurationError
- Defined in:
- lib/mcp_toolkit/errors/configuration_error.rb
Overview
The toolkit was used before it was configured, or a required piece of configuration is missing for the operation being attempted.